aboutsummaryrefslogtreecommitdiff
path: root/src/profiling/NullProfilingConnection.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/profiling/NullProfilingConnection.hpp')
-rw-r--r--src/profiling/NullProfilingConnection.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/profiling/NullProfilingConnection.hpp b/src/profiling/NullProfilingConnection.hpp
index a72d7bfb82..ef09794ec5 100644
--- a/src/profiling/NullProfilingConnection.hpp
+++ b/src/profiling/NullProfilingConnection.hpp
@@ -9,10 +9,10 @@
#include <armnn/utility/IgnoreUnused.hpp>
-namespace armnn
+namespace arm
{
-namespace profiling
+namespace pipe
{
class NullProfilingConnection : public IProfilingConnection
@@ -36,6 +36,6 @@ class NullProfilingConnection : public IProfilingConnection
};
-} // namespace profiling
+} // namespace pipe
-} // namespace armnn \ No newline at end of file
+} // namespace arm \ No newline at end of file